package xmlutil.test;

import xmlutil.XMLUtil;

import java.io.FileReader;
import java.io.File;
import java.io.PrintStream;

import java.util.Hashtable;
import java.util.Vector;
import java.util.Enumeration;

import org.xml.sax.Parser;
import org.xml.sax.InputSource;

/** A unit testing module */
public class Test
{
    public static void main(String args[])
    {
	// Open files.
	for (int i = 0; i < args.length; i++) {
	    try {
		File f = new File (args[i]);
		
		// Create an xml util and direct a sax stream
		// at it.
		XMLUtil xu = new XMLUtil ();
		Parser parser = new org.apache.xerces.parsers.SAXParser ();
		parser.setDocumentHandler (xu);
		InputSource is = new InputSource (new FileReader (f));
		parser.parse (is);

		// Now try to dump the contents we find.
		Dump (0, xu.getResult(), System.out);
	    } catch (Exception e) {
		System.err.println ("With file " + args[i] + ":");
		e.printStackTrace ();
	    }
	}
    }

    public static void printIndent (int indent, PrintStream out) {
	while (indent-- != 0) out.print (" ");
    }

    public static void Dump (int indent, Object o, PrintStream out) {
	if (o instanceof Hashtable) DumpHash ( indent, (Hashtable) o, out );
	else if (o instanceof Vector) DumpVect ( indent, (Vector) o, out );
	else if (o instanceof String) DumpStr ( indent, (String) o, out );
	else {
	    printIndent (indent, out);
	    out.println ("unknown: " + o);
	}
    }

    public static void DumpHash (int indent, Hashtable h, PrintStream out) {
	printIndent (indent, out);
	out.println ("hash:");

	indent += 2;

	Enumeration keys = h.keys ();
	while (keys.hasMoreElements()) {
	    Object k = keys.nextElement ();
	    Object v = h.get (k);
	    printIndent (indent, out);
	    out.println ("key:");
	    Dump (indent+2, k, out);

	    printIndent (indent, out);
	    out.println ("value:");
	    Dump (indent+2, v, out);
	}
    }

    public static void DumpVect (int indent, Vector v, PrintStream out)
    {
	printIndent (indent, out);
	out.println ("vect:");
	indent += 2;
	Enumeration e = v.elements ();
	while (e.hasMoreElements()) {
	    Dump (indent, e.nextElement(), out);
	}
    }

    public static void DumpStr (int indent, String s, PrintStream out) {
	printIndent(indent, out);
	out.println ("String: "+s);
    }
}
